@@ -1,10 +1,5 @@
 #!/usr/bin/perl
 
-BEGIN {
-  push @INC , '../';  
-  push @INC , '../SVG';
-}
-
   use SVG;
   use strict;
   use CGI ':new :header';
