@@ -1,10 +1,12 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 
 use strict;
 use CGI;
 
 use SVG;
 
+my $VERSION = 3;
+
 #---------Create the CGI object which is required to handle the header
 my $p = CGI->new();
 
@@ -25,102 +27,6 @@ my $width = $p->param('w') || 800;
 
 my $svg= SVG->new(width=>$width,height=>$height); 
 
-my %line_style = ('stroke-miterlimit'=>(4*rand()),
-          'stroke-linejoin'=>'miter',
-          'stroke-linecap'=>'round',
-          'stroke-width'=>(0.1+5*rand()),
-          'stroke-opacity'=>(0.5+0.5*rand()),
-          'stroke'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'fill-opacity'=>(0.5+0.5*rand()),
-          'fill'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'opacity'=>(0.5+0.5*rand()) );
-          
-my %circle_style = ('stroke-miterlimit'=>(4*rand()),
-          'stroke-linejoin'=>'miter',
-          'stroke-linecap'=>'round',
-          'stroke-width'=>(0.1+0.5*rand()),
-          'stroke-opacity'=>(0.5+0.5*rand()),
-          'stroke'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'fill-opacity'=>(0.5+0.5*rand()),
-          'fill'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'opacity'=>(0.5+0.5*rand()) );
-
-my %polyline_style = ('stroke-miterlimit'=>(4*rand()),
-          'stroke-linejoin'=>'miter',
-          'stroke-linecap'=>'round',
-          'stroke-width'=>(0.1+0.5*rand()),
-          'stroke-opacity'=>(0.5+0.5*rand()),
-          'stroke'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'fill-opacity'=>(0.5+0.5*rand()),
-          'fill'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'opacity'=>(0.5+0.5*rand()) );
-
-my %rectangle_style = ('stroke-miterlimit'=>(4*rand()),
-          'stroke-linejoin'=>'miter',
-          'stroke-linecap'=>'round',
-          'stroke-width'=>(0.1+0.5*rand()),
-          'stroke-opacity'=>(0.5+0.5*rand()),
-          'stroke'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'fill-opacity'=>(0.5+0.5*rand()),
-          'fill'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'opacity'=>(0.5+0.5*rand()) );
-
-
-my %polygon_style = ('stroke-miterlimit'=>(4*rand()),
-          'stroke-linejoin'=>'miter',
-          'stroke-linecap'=>'round',
-          'stroke-width'=>(0.1+0.5*rand()),
-          'stroke-opacity'=>(0.5+0.5*rand()),
-          'stroke'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'fill-opacity'=>(0.5+0.5*rand()),
-          'fill'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'opacity'=>(0.5+0.5*rand()) );
-
-
-my %text_style = ('font-family'=>'Arial',
-          'font-size'=>8+5*rand(),
-          'stroke-width'=>1+2*rand(),
-          'stroke-opacity'=>(0.5+0.5*rand()),
-          'stroke'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'fill-opacity'=>1,
-          'fill'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'opacity'=>(0.5+0.5*rand()) );
-
-my %text_style_1 = ('font-family'=>'Arial',
-          'font-size'=>8+5*rand(),
-          'stroke-width'=>1+2*rand(),
-          'stroke-opacity'=>(0.5+0.5*rand()),
-          'stroke'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'fill-opacity'=>1,
-          'fill'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'opacity'=>(0.5+0.5*rand()) );
-
-my %text_style_2 = ('font-family'=>'Arial',
-          'font-size'=>8+5*rand(),
-          'stroke-width'=>1+2*rand(),
-          'stroke-opacity'=>(0.2+0.5*rand()),
-          'stroke'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'fill-opacity'=>1,
-          'fill'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'opacity'=>(0.5+0.5*rand()) );
-
-my %text_style_3 = ('font-family'=>'Arial',
-          'font-size'=>8+5*rand(),
-          'stroke-width'=>1+2*rand(),
-          'stroke-opacity'=>(0.5+0.2*rand()),
-          'stroke'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'fill-opacity'=>1,
-          'fill'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'opacity'=>(0.5+0.5*rand()) );
-
-my %text_style_4 = ('font-family'=>'Arial',
-          'font-size'=>8+5*rand(),
-          'stroke-width'=>1+2*rand(),
-          'stroke-opacity'=>(0.5+0.3*rand()),
-          'stroke'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'fill-opacity'=>1,
-          'fill'=>'rgb('.255*rand().','.255*rand().','.255*rand().')',
-          'opacity'=>(0.5+0.5*rand()) );
 
 my $y=$svg->group( id=>'group_generated_group',style=>{ stroke=>'red', fill=>'green' });
 
@@ -138,55 +44,64 @@ my $line = $svg->line(id=>'l1',x1=>(rand()*$width+5),
           y1=>(rand()*$height+5),
           x2=>(rand()*$width-5),
           y2=>(rand()*$height-5),
-          style=>\%line_style,);
+          style=>&obj_style,);
 
 #---------
-my $myX = -$width*rand();
-my $myY = -$height*rand();
+foreach  (1..&round_up(rand(10))) {
+    my $myX = -$width*rand();
+    my $myY = -$height*rand();
 
+    $y->rectangle (x=>$width/2,
+                   y=>$height/2,
+                   width=>(50+50*rand()),
+                   height=>(50+50*rand()),
+                   rx=>20*rand(),
+                   ry=>20*rand(),
+                   id=>'rect_1',
+                   style=>&obj_style);
 
-$y->rectangle (x=>$width/2,
-               y=>$height/2,
-               width=>(50+50*rand()),
-               height=>(50+50*rand()),
-               rx=>20*rand(),
-               ry=>20*rand(),
-               id=>'rect_1',
-               style=>\%rectangle_style);
-
-$y->animate(attributeName=>'transform', 
-            attributeType=>'XML',
-            from=>'0 0',
-            to=>$myX.' '.$myY,
-            dur=>20*rand().'s',
-            repeatCount=>'20',
-            restart=>'always',
-            -method=>'Transform',);
-
+    $y->animate(attributeName=>'transform', 
+                attributeType=>'XML',
+                from=>'0 0',
+                to=>$myX.' '.$myY,
+                dur=>20*rand().'s',
+                repeatCount=>&round_up(rand(30)),
+                restart=>'always',
+                -method=>'Transform',);
+}
 my $a = $z -> anchor(
 		-href   => 'http://somewhere.org/some/other/page.html',
-		-target => 'new_window_0');
+		-target => 'new_window_0',
+        id=>'anchor a');
 
 my $a1 = $z -> anchor(
 		-href   => '/index.html',
-		-target => 'new_window_1');
+		-target => 'new_window_1',
+        id=>'anchor a1');
 
 my $a2 = $z -> anchor(
 		-href   => '/svg/index.html',
-		-target => 'new_window_2');
+		-target => 'new_window_2',
+        id=>'anchor a2');
 
+#---------
 
-my $c = $a->circle(cx=>($width-20)*rand(),
+my $c;
+foreach  (1..&round_up(rand(10))) {
+
+    $c= $a->circle(cx=>($width-20)*rand(),
                     cy=>($height-20)*rand(),
                     r=>100*rand(), 
                     id=>'c1',
-                    style=>\%circle_style);
+                    style=>&obj_style);
 
-$c = $a1->circle(cx=>($width-20)*rand(),
+    $c = $a1->circle(cx=>($width-20)*rand(),
                     cy=>($height-20)*rand(),
                     r=>100*rand(), 
                     id=>'c2',
-                    style=>\%circle_style);
+                    style=>&obj_style);
+}
+#---------
 
 my $xv = [$width*rand(), $width*rand(), $width*rand(), $width*rand()];
 
@@ -200,8 +115,9 @@ my $points = $a->get_path(x=>$xv,
 
 $c = $a1->polyline (%$points,
                     id=>'pline1',
-                    style=>\%polyline_style);
+                    style=>&obj_style);
 
+#---------
 
 $xv = [$width*rand(), $width*rand(), $width*rand(), $width*rand()];
 
@@ -214,42 +130,102 @@ $points = $a->get_path(x=>$xv,
 
 $c = $a->polygon (%$points,
                     id=>'pgon1',
-                    style=>\%polygon_style);
+                    style=>&obj_style);
+#---------
+
 
 my $t=$a2->text(id=>'t1',
                 transform=>'rotate(-45)',
-                style=>\%text_style);
+                style=>&text_style);
+#---------
 
-my $t=$a2->text(id=>'t3',
+
+my $u=$a2->text(id=>'t3',
               x=>$width/2*rand(),
               y=>($height-80)*rand(),
               transform=>'rotate('.(-2.5*5*rand()).')',
-              style=>\%text_style_1);
+              style=>&text_style);
+
+
 
 my $v=$a2->tag('text',
               id=>'t5',
               x=>$width/2*rand(),
               y=>$height-40+5*rand(),
               transform=>'rotate('.(-2.5*5*rand()).')',
-              style=>\%text_style_3);
+              style=>&text_style);
 
 my $w=$a2->text(id=>'t5',
               x=>$width/2*rand(),
               y=>$height-20+5*rand(),
               transform=>'rotate('.(-2.5*5*rand()).')',
-              style=>\%text_style_4);
+              style=>&text_style);
 
 
 $t->cdata('Text generated using the high-level "text" tag');
+$t->cdata('Courtesy of RO IT Systems GmbH');
 $v->cdata('Text generated using the low-level "tag" tag');
-$w->cdata('Hackmarish perl!');
-$w->cdata('and more perl Hackmarish perl!');
+$w->cdata('But what about in-line SVG? Yes, we do that too');
+$w->cdata('All this with SVG.pm? Wow.');
 
 print $p->header('image/svg-xml');
 print $svg->xmlify;
 
 exit;
 
-__END__
+
+#################
+# Subroutine to round up the value of a number or of a text representation of number
+# 
+sub round_up {
+    my ($x, $precision) = shift;
+    $x =~ s/^\s+//g;
+    $x =~ s/\s+$//g;
+    $x =~ s/,//g;
+
+    my $y;
+    $precision = 0 unless $precision;
+    ($x, $y) =  split( /\./, $x) if $x =~ /\./;
+    my $y1 = substr($y, 0, $precision);
+    my $y2 = substr($y, $precision, 1);
+
+    if ($y2 >= 5) {
+        $precision?$y1++:$x++;
+    }
+
+    return "$x$y1";
+
+} # sub round_val
+
+sub obj_style {
+
+    my $style = {'stroke-miterlimit'=>(4*rand()),
+          'stroke-linejoin'=>'miter',
+          'stroke-linecap'=>'round',
+          'stroke-width'=>(0.1+0.5*rand()),
+          'stroke-opacity'=>(0.5+0.5*rand()),
+          'stroke'=>'rgb('.255*round_up(rand()).','.255*round_up(rand()).','.255*round_up(rand()).')',
+          'fill-opacity'=>(0.5+0.5*rand()),
+          'fill'=>'rgb('.255*round_up(rand()).','.255*round_up(rand()).','.255*round_up(rand()).')',
+          'opacity'=>(0.5+0.5*rand()) };
+
+    return $style;
+
+}
+
+sub text_style {
+
+    my $style = {'font-family'=>'Arial',
+          'font-size'=>8+5*rand(),
+          'stroke-width'=>1+2*rand(),
+          'stroke-opacity'=>(0.2+0.5*rand()),
+          'stroke'=>'rgb('.255*round_up(rand()).','.255*round_up(rand()).','.255*round_up(rand()).')',
+          'fill-opacity'=>1,
+          'fill'=>'rgb('.255*round_up(rand()).','.255*round_up(rand()).','.255*round_up(rand()).')',
+          'opacity'=>(0.5+0.5*rand()) };
+
+    return $style;
+
+}
 
 #---------
